@@ -419,7 +419,7 @@ namespace tr1
 
 //======================================================================
 // include
-#include "../iutest_ver.h"
+#include "../iutest_ver.hpp"
 #include <gtest/gtest.h>
 #include "iutest_gtest_ver.hpp"
 
@@ -455,6 +455,10 @@ namespace tr1
 #undef IUTEST_ASSERT_STRCASEEQ
 #undef IUTEST_ASSERT_STRCASENE
 #undef IUTEST_ASSERT_THROW
+#undef IUTEST_ASSERT_THROW_VALUE_EQ
+#undef IUTEST_ASSERT_THROW_VALUE_NE
+#undef IUTEST_ASSERT_THROW_VALUE_STREQ
+#undef IUTEST_ASSERT_THROW_VALUE_STRCASEEQ
 #undef IUTEST_ASSERT_NO_THROW
 #undef IUTEST_ASSERT_ANY_THROW
 #undef IUTEST_ASSERT_NO_FATAL_FAILURE
@@ -489,6 +493,10 @@ namespace tr1
 #undef IUTEST_EXPECT_STRCASEEQ
 #undef IUTEST_EXPECT_STRCASENE
 #undef IUTEST_EXPECT_THROW
+#undef IUTEST_EXPECT_THROW_VALUE_EQ
+#undef IUTEST_EXPECT_THROW_VALUE_NE
+#undef IUTEST_EXPECT_THROW_VALUE_STREQ
+#undef IUTEST_EXPECT_THROW_VALUE_STRCASEEQ
 #undef IUTEST_EXPECT_NO_THROW
 #undef IUTEST_EXPECT_ANY_THROW
 #undef IUTEST_EXPECT_NO_FATAL_FAILURE
@@ -523,6 +531,10 @@ namespace tr1
 #undef IUTEST_INFORM_STRCASEEQ
 #undef IUTEST_INFORM_STRCASENE
 #undef IUTEST_INFORM_THROW
+#undef IUTEST_INFORM_THROW_VALUE_EQ
+#undef IUTEST_INFORM_THROW_VALUE_NE
+#undef IUTEST_INFORM_THROW_VALUE_STREQ
+#undef IUTEST_INFORM_THROW_VALUE_STRCAEEQ
 #undef IUTEST_INFORM_NO_THROW
 #undef IUTEST_INFORM_ANY_THROW
 #undef IUTEST_INFORM_NO_FATAL_FAILURE
@@ -545,6 +557,10 @@ namespace tr1
 #undef IUTEST_EXPECT_FAIL_AT
 #undef IUTEST_SCOPED_TRACE
 
+#undef IUTEST_ASSERT_FAILURE
+#undef IUTEST_EXPECT_FAILURE
+#undef IUTEST_INFORM_FAILURE
+
 #undef IUTEST_PRED_FORMAT1_
 #undef IUTEST_PRED_FORMAT2_
 #undef IUTEST_PRED_FORMAT3_
@@ -572,6 +588,8 @@ namespace tr1
 #undef IUTEST_HAS_PARAM_TEST
 #undef IUTEST_HAS_COMBINE
 #undef IUTEST_HAS_VARIADIC_COMBINE
+#undef IUTEST_HAS_PAIRWISE
+#undef IUTEST_HAS_VARIADIC_PAIRWISE
 #undef IUTEST_HAS_TYPED_TEST
 #undef IUTEST_HAS_TYPED_TEST_P
 
@@ -592,6 +610,7 @@ namespace tr1
 #undef IUTEST_HAS_SEH
 
 #undef IUTEST_INIT
+#undef IUTEST_SKIP
 
 #undef IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING
 
@@ -629,6 +648,15 @@ namespace tr1
 #undef IUTEST_TEST_CLASS_NAME_
 #undef IUTEST_TEST_
 
+#undef IUTEST_TEST_THROW_VALUE_
+#undef IUTEST_TEST_THROW_VALUE_EQ_
+#undef IUTEST_TEST_THROW_VALUE_NE_
+#undef IUTEST_TEST_THROW_VALUE_STREQ_
+#undef IUTEST_TEST_THROW_VALUE_STRCASEEQ_
+
+#undef IUTEST_PP_CAT
+#undef IUTEST_IS_NULLLITERAL
+
 #endif
 
 // INFORM Ή̂߂ɁA֐Ă
@@ -667,9 +695,13 @@ namespace tr1
 #define IUTEST_ASSERT_STRLNEQ(len, v2)			ASSERT_PRED_FORMAT2(iuutil::CmpHelperSTRLNEQ, len, v2)
 #define IUTEST_ASSERT_STRCASEEQ	ASSERT_STRCASEEQ
 #define IUTEST_ASSERT_STRCASENE	ASSERT_STRCASENE
-#define IUTEST_ASSERT_THROW(statement, expected_exception)		ASSERT_THROW((void)statement, expected_exception)
-#define IUTEST_ASSERT_NO_THROW(statement)						ASSERT_NO_THROW((void)statement)
-#define IUTEST_ASSERT_ANY_THROW(statement)						ASSERT_ANY_THROW((void)statement)
+#define IUTEST_ASSERT_THROW(statement, expected_exception)		ASSERT_THROW((void)(statement), expected_exception)
+#define IUTEST_ASSERT_THROW_VALUE_EQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_THROW_VALUE_NE(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_NO_THROW(statement)						ASSERT_NO_THROW((void)(statement))
+#define IUTEST_ASSERT_ANY_THROW(statement)						ASSERT_ANY_THROW((void)(statement))
 #define IUTEST_ASSERT_NO_FATAL_FAILURE		ASSERT_NO_FATAL_FAILURE
 
 #ifdef GTEST_OS_WINDOWS
@@ -708,9 +740,13 @@ namespace tr1
 #define IUTEST_EXPECT_STRLNEQ(len, v2)			EXPECT_PRED_FORMAT2(iuutil::CmpHelperSTRLNEQ, len, v2)
 #define IUTEST_EXPECT_STRCASEEQ	EXPECT_STRCASEEQ
 #define IUTEST_EXPECT_STRCASENE	EXPECT_STRCASENE
-#define IUTEST_EXPECT_THROW(statement, expected_exception)	EXPECT_THROW((void)statement, expected_exception)
-#define IUTEST_EXPECT_NO_THROW(statement)					EXPECT_NO_THROW((void)statement)
-#define IUTEST_EXPECT_ANY_THROW(statement)					EXPECT_ANY_THROW((void)statement)
+#define IUTEST_EXPECT_THROW(statement, expected_exception)	EXPECT_THROW((void)(statement), expected_exception)
+#define IUTEST_EXPECT_THROW_VALUE_EQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_THROW_VALUE_NE(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_NO_THROW(statement)					EXPECT_NO_THROW((void)(statement))
+#define IUTEST_EXPECT_ANY_THROW(statement)					EXPECT_ANY_THROW((void)(statement))
 #define IUTEST_EXPECT_NO_FATAL_FAILURE		EXPECT_NO_FATAL_FAILURE
 
 #ifdef GTEST_OS_WINDOWS
@@ -826,9 +862,13 @@ namespace tr1
 #define IUTEST_INFORM_STRLNEQ(len, v2)			INFORM_PRED_FORMAT2(iuutil::CmpHelperSTRLNEQ, len, v2)
 #define IUTEST_INFORM_STRCASEEQ	INFORM_STRCASEEQ
 #define IUTEST_INFORM_STRCASENE	INFORM_STRCASENE
-#define IUTEST_INFORM_THROW(statement, expected_exception)	INFORM_THROW((void)statement, expected_exception)
-#define IUTEST_INFORM_NO_THROW(statement)					INFORM_NO_THROW((void)statement)
-#define IUTEST_INFORM_ANY_THROW(statement)					INFORM_ANY_THROW((void)statement)
+#define IUTEST_INFORM_THROW(statement, expected_exception)	INFORM_THROW((void)(statement), expected_exception)
+#define IUTEST_INFORM_THROW_VALUE_EQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#define IUTEST_INFORM_THROW_VALUE_NE(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#define IUTEST_INFORM_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#define IUTEST_INFORM_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#define IUTEST_INFORM_NO_THROW(statement)					INFORM_NO_THROW((void)(statement))
+#define IUTEST_INFORM_ANY_THROW(statement)					INFORM_ANY_THROW((void)(statement))
 #define IUTEST_INFORM_NO_FATAL_FAILURE		INFORM_NO_FATAL_FAILURE
 
 
@@ -871,8 +911,15 @@ namespace tr1
 
 #define IUTEST_SCOPED_TRACE		SCOPED_TRACE
 
+#define IUTEST_ASSERT_FAILURE	GTEST_FATAL_FAILURE_
+#define IUTEST_EXPECT_FAILURE	GTEST_NONFATAL_FAILURE_
+#define IUTEST_INFORM_FAILURE	GTEST_INFORM_FAILURE_
+
 #define IUTEST_FLAG				GTEST_FLAG
 
+#define IUTEST_SKIP()			GTEST_AMBIGUOUS_ELSE_BLOCKER_	\
+								if( testing::internal::AlwaysTrue() ) return
+
 #define IUTEST_TYPED_TEST_CASE		TYPED_TEST_CASE
 #define IUTEST_TYPED_TEST			TYPED_TEST
 #define IUTEST_TYPED_TEST_CASE_P	TYPED_TEST_CASE_P
@@ -883,6 +930,8 @@ namespace tr1
 #define IUTEST_HAS_PARAM_TEST		GTEST_HAS_PARAM_TEST
 #define IUTEST_HAS_COMBINE			GTEST_HAS_COMBINE
 #define IUTEST_HAS_VARIADIC_COMBINE	0
+#define IUTEST_HAS_PAIRWISE				0
+#define IUTEST_HAS_VARIADIC_PAIRWISE	0
 #define IUTEST_HAS_TYPED_TEST		GTEST_HAS_TYPED_TEST
 #define IUTEST_HAS_TYPED_TEST_P		GTEST_HAS_TYPED_TEST_P
 
@@ -934,6 +983,41 @@ namespace tr1
 
 #define IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING	GTEST_SUPPRESS_UNREACHABLE_CODE_WARNING_BELOW_
 
+#define IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, pred_formatter)	\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_													\
+	if( ::testing::AssertionResult ar = ::testing::AssertionSuccess() ) {			\
+		try {																		\
+			IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING((void)statement);				\
+			ar << "\nExpected: " #statement " throws an exception of type "			\
+				  #expected_exception ".\n  Actual: it throws nothing.";			\
+			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
+		} catch( expected_exception const& e) {										\
+			if( ::testing::AssertionResult ar2 = pred_formatter("e", #expected_exception_value, e, expected_exception_value) ) {			\
+			} else {																\
+				ar << "\nExpected: " #statement " throws an exception of value\n" << ar2.message();	\
+				goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);				\
+			}																		\
+		} catch( ... ) {															\
+			ar << "\nExpected: " #statement " throws an exception of type "			\
+	          #expected_exception ".\n  Actual: it throws a different type.";		\
+			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
+		}																			\
+	} else																			\
+		IUTEST_PP_CAT(iutest_label_throw_value, __LINE__):							\
+		on_failure(ar.message())
+
+#define IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::testing::internal::EqHelper<GTEST_IS_NULL_LITERAL_(expected_exception_value)>::Compare)
+#define IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::testing::internal::NeHelper<GTEST_IS_NULL_LITERAL_(expected_exception_value)>::Compare)
+#define IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::testing::internal::CmpHelperSTREQ)
+#define IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_exception_value, on_failure)	\
+	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, ::testing::internal::CmpHelperSTRCASEEQ)
+
+#define IUTEST_PP_CAT	GTEST_CONCAT_TOKEN_
+#define IUTEST_IS_NULLLITERAL	GTEST_IS_NULL_LITERAL_
+
 namespace testing
 {
 
@@ -1163,12 +1247,21 @@ public:
 }	// end of namespace internal
 
 // tuple
-namespace tuple
+namespace tuples
 {
 	using ::std::tr1::tuple;
+	using ::std::tr1::tuple_size;
+	using ::std::tr1::tuple_element;
+	using ::std::tr1::make_tuple;
 	using ::std::tr1::get;
 }
 
+using tuples::tuple;
+using tuples::tuple_size;
+using tuples::tuple_element;
+using tuples::make_tuple;
+using tuples::get;
+
 namespace iusupport
 {
 	class iuDefaultPrinter : public ::testing::EmptyTestEventListener
@@ -1225,7 +1318,7 @@ namespace iusupport
 namespace iutest = testing;
 #endif
 
-#include "../internal/iutest_pragma.h"
+#include "../internal/iutest_pragma.hpp"
 #include "../iutest_util.hpp"
 
 #ifndef INCG_IRIS_iutest_HPP_
