@@ -23,7 +23,7 @@
 
 //======================================================================
 // include
-#include "iutest_ver.h"
+#include "iutest_ver.hpp"
 #include "iutest_param_tests.hpp"
 #include "iutest_typed_tests.hpp"
 #include "iutest_prod.hpp"
@@ -306,6 +306,42 @@ namespace iutest
 													IUTEST_TEST_THROW_(statement, expected_exception, IUTEST_ASSERT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	throw value == eXg
+*/
+#ifndef IUTEST_ASSERT_THROW_VALUE_EQ
+#  define IUTEST_ASSERT_THROW_VALUE_EQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	throw value != eXg
+*/
+#ifndef IUTEST_ASSERT_THROW_VALUE_NE
+#  define IUTEST_ASSERT_THROW_VALUE_NE(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	throw value v eXg
+*/
+#ifndef IUTEST_ASSERT_THROW_VALUE_STREQ
+#  define IUTEST_ASSERT_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	throw value vi啶ʂȂj eXg
+*/
+#ifndef IUTEST_ASSERT_THROW_VALUE_STRCASEEQ
+#  define IUTEST_ASSERT_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_ASSERT_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	any throw eXg
@@ -508,6 +544,42 @@ namespace iutest
 													IUTEST_TEST_THROW_(statement, expected_exception, IUTEST_EXPECT_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	throw value == eXg
+*/
+#ifndef IUTEST_EXPECT_THROW_VALUE_EQ
+#  define IUTEST_EXPECT_THROW_VALUE_EQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	throw value != eXg
+*/
+#ifndef IUTEST_EXPECT_THROW_VALUE_NE
+#  define IUTEST_EXPECT_THROW_VALUE_NE(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	throw value v eXg
+*/
+#ifndef IUTEST_EXPECT_THROW_VALUE_STREQ
+#  define IUTEST_EXPECT_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	throw value vi啶ʂȂj eXg
+*/
+#ifndef IUTEST_EXPECT_THROW_VALUE_STRCASEEQ
+#  define IUTEST_EXPECT_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_EXPECT_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	any throw eXg
@@ -718,6 +790,42 @@ namespace iutest
 													IUTEST_TEST_THROW_(statement, expected_exception, IUTEST_INFORM_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	throw value == eXg
+*/
+#ifndef IUTEST_INFORM_THROW_VALUE_EQ
+#  define IUTEST_INFORM_THROW_VALUE_EQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_EQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	throw value != eXg
+*/
+#ifndef IUTEST_INFORM_THROW_VALUE_NE
+#  define IUTEST_INFORM_THROW_VALUE_NE(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_NE_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	throw value v eXg
+*/
+#ifndef IUTEST_INFORM_THROW_VALUE_STREQ
+#  define IUTEST_INFORM_THROW_VALUE_STREQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STREQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_INFORM_
+ * @brief	throw value vi啶ʂȂj eXg
+*/
+#ifndef IUTEST_INFORM_THROW_VALUE_STRCASEEQ
+#  define IUTEST_INFORM_THROW_VALUE_STRCASEEQ(statement, expected_exception, expected_value)	\
+													IUTEST_TEST_THROW_VALUE_STRCASEEQ_(statement, expected_exception, expected_value, IUTEST_INFORM_FAILURE)
+#endif
+
 /**
  * @ingroup	IUTEST_INFORM_
  * @brief	any throw eXg
@@ -744,6 +852,14 @@ namespace iutest
 #  define IUTEST_INFORM_NO_FATAL_FAILURE(statement)	IUTEST_TEST_NO_FATAL_FAILURE_(statement, IUTEST_INFORM_FAILURE)
 #endif
 
+/**
+ * @ingroup	IUTEST_UTIL
+ * @brief	eXg̖IȃXLbv
+*/
+#ifndef IUTEST_SKIP
+#  define IUTEST_SKIP()								IUTEST_TEST_SKIP()
+#endif
+
 
 /**
  * @brief iutest root namespace
