@@ -20,8 +20,8 @@
 //======================================================================
 // include
 #include "iutest_body.hpp"
-#include "internal/iutest_factory.h"
-#include "internal/iutest_exception.h"
+#include "internal/iutest_factory.hpp"
+#include "internal/iutest_exception.hpp"
 
 namespace iutest
 {
@@ -70,7 +70,9 @@ public:
 		, m_testname(name)
 		, m_factory(factory)
 		, m_should_run(true)
+		, m_ran(false)
 		, m_disable(false)
+		, m_skip(false)
 	{
 		m_mediator.SetPointer(this);
 		if( strstr(name, "DISABLED_") == name )
@@ -90,6 +92,8 @@ public:
 	bool			is_ran(void)			const	{ return m_ran; }
 	/** disable */
 	bool			is_disabled_test(void)	const	{ return m_disable; }
+	/** is skipped */
+	bool			is_skipped(void)		const	{ return !m_should_run || m_skip; }
 	/** eXg̎s~b */
 	TimeInMillisec	elapsed_time(void)		const	{ return m_test_result.elapsed_time(); }
 	/** eXgʂ̎擾 */
@@ -262,6 +266,7 @@ private:
 	void	clear(void)
 	{
 		m_ran = false;
+		m_skip = false;
 		m_test_result.ClearResult();
 	}
 
@@ -303,6 +308,7 @@ private:
 	bool					m_should_run;		//!< sׂ̐^Ul
 	bool					m_ran;				//!< sǂ
 	bool					m_disable;			//!< ^Ul
+	bool					m_skip;				//!< XLbvǂ
 
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(TestInfo);
 };
