@@ -23,16 +23,6 @@
 
 IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
 
-//======================================================================
-// define
-/**
- * @ingroup	IUTEST_CONFIG
- * @brief	xml o͂ skipped ^O܂߂邩ǂ
-*/
-#ifndef IUTEST_REPORT_SKIPPED
-#  define IUTEST_REPORT_SKIPPED		1
-#endif
-
 namespace iutest
 {
 
@@ -128,8 +118,10 @@ public:
 private:
 	static void OnReportTestCase(IFile* file, const TestCase& test_case)
 	{
-		file->Printf("  <testsuite name=\"%s\" tests=\"%d\" failures=\"%d\" disabled=\"%d\" "
-			, EscapeXmlAttribute(test_case.name()).c_str()
+		file->Printf("  <testsuite ");
+		OutputXmlAttribute(file, "name"
+			, EscapeXmlAttribute(test_case.name()).c_str() );
+		file->Printf("tests=\"%d\" failures=\"%d\" disabled=\"%d\" "
 			, test_case.total_test_count()
 			, test_case.failed_test_count()
 			, test_case.disabled_test_count()
@@ -149,14 +141,14 @@ private:
 	}
 	static void OnReportTestInfo(IFile* file, const TestInfo& test_info)
 	{
-		file->Printf("    <testcase name=\"%s\" ", EscapeXmlAttribute(test_info.name()).c_str() );
-		bool should_run = test_info.should_run();
+		file->Printf("    <testcase ");
+		OutputXmlAttribute(file, "name", EscapeXmlAttribute(test_info.name()).c_str() );
 
 		{
 			const char* type_param = test_info.type_param();
 			if( type_param != NULL )
 			{
-				file->Printf("type_param=\"%s\" "
+				OutputXmlAttribute(file, "type_param"
 					, EscapeXmlAttribute(type_param).c_str() );
 			}
 		}
@@ -164,7 +156,7 @@ private:
 			const char* value_param = test_info.value_param();
 			if( value_param != NULL )
 			{
-				file->Printf("value_param=\"%s\" "
+				OutputXmlAttribute(file, "value_param"
 					, EscapeXmlAttribute(value_param).c_str() );
 			}
 		}
@@ -176,7 +168,7 @@ private:
 		file->Printf("time=\"%s\" "
 			, detail::FormatTimeInMillisecAsSecond(test_info.elapsed_time()).c_str()
 			);
-		file->Printf("classname=\"%s\""
+		OutputXmlAttribute(file, "classname"
 			, EscapeXmlAttribute(test_info.test_case_name()).c_str() );
 
 		// propertys
@@ -191,7 +183,8 @@ private:
 			}
 		}
 
-		if( test_info.HasFailure() )
+		bool notrun = test_info.should_run() && !test_info.is_ran();
+		if( test_info.HasFailure() || notrun )
 		{
 			file->Printf(">\n");
 			for( int i=0, count=test_info.result()->total_part_count(); i < count; ++i )
@@ -199,21 +192,29 @@ private:
 				const TestPartResult& part = test_info.result()->GetTestPartResult(i);
 				if( part.passed() ) continue;
 
-				file->Printf("      <failure message=\"");
-				file->Printf(EscapeXmlAttribute(part.summary()).c_str());
-				file->Printf("\" type=\"\">");
+				file->Printf("      <failure ");
+				OutputXmlAttribute(file, "message"
+					, EscapeXmlAttribute(part.summary()).c_str());
+				file->Printf("type=\"\">");
 				::std::string message = detail::FormatCompilerIndependentFileLocation(part.file_name(), part.line_number());
 				message += "\n";
-				message += part.summary();
+				message += detail::MultiByteStringToUTF8(part.summary());
 				OutputXmlCDataSection(file, message.c_str());
 				file->Printf("\n      </failure>\n");
 			}
+			if( notrun )
+			{
+				file->Printf("      <failure message=\"Not Run\" type=\"\">");
+				OutputXmlCDataSection(file, "Not Run");
+				file->Printf("\n      </failure>\n");
+			}
 			file->Printf("    </testcase>\n");
 		}
 		else
 		{
 #if IUTEST_REPORT_SKIPPED
-			if( !should_run )
+			bool skipped = test_info.is_skipped();
+			if( skipped )
 			{
 				file->Printf(">\n");
 				file->Printf("      <skipped />\n");
@@ -251,9 +252,15 @@ private:
 	static void	OutputXmlCDataSection(IFile* file, const char* data)
 	{
 		file->Printf("<![CDATA[");
-		file->Printf(data);
+		file->Write(data, strlen(data), 1);
 		file->Printf("]]>");
 	}
+	static void OutputXmlAttribute(IFile* file, const char* name, const char* value)
+	{
+		file->Printf("%s=\"", name);
+		file->Write(value, strlen(value), 1 );
+		file->Printf("\" ");
+	}
 
 private:
 	static ::std::string EscapeXmlAttribute(const char* str)
@@ -298,18 +305,27 @@ private:
 						msg += "\"";
 					break;
 				default:
-					if( IsValidXmlCharacter(*src) )
 					{
-						if( is_attribute
-							&& IsWhitespace(*src) )
+						wchar_t wc = 0;
+						int len = mbtowc(&wc, src, MB_CUR_MAX);
+						if( len > 1 )
 						{
-							char tmp[8];
-							sprintf(tmp, "&#x%02X;", *src);
-							msg += tmp;
+							msg += detail::WideStringToUTF8(&wc, 1);
+							src += len-1;
 						}
-						else
+						else if( IsValidXmlCharacter(*src) )
 						{
-							msg += *src;
+							if( is_attribute
+								&& IsWhitespace(*src) )
+							{
+								char tmp[8];
+								sprintf(tmp, "&#x%02X;", *src);
+								msg += tmp;
+							}
+							else
+							{
+								msg += *src;
+							}
 						}
 					}
 					break;
