@@ -22,16 +22,19 @@
 #include "iutest_basic_tests.cpp"
 #include "iutest_combine_tests.cpp"
 #include "iutest_compatibility_tests.cpp"
+#include "iutest_filepath_tests.cpp"
 #include "iutest_fixture_tests.cpp"
 #include "iutest_floatingpoint_tests.cpp"
 #include "iutest_no_fatalfailure_tests.cpp"
 #include "iutest_param_test_tests1.cpp"
 #include "iutest_param_test_tests2.cpp"
+#include "iutest_param_method_tests.cpp"
 #include "iutest_pred_tests.cpp"
 #include "iutest_prod_tests.cpp"
 #include "iutest_spi_tests.cpp"
 #include "iutest_string_assertion_tests.cpp"
 #include "iutest_tr1_value_tmp_tests.cpp"
+#include "iutest_pairwise_tests.cpp"
 #include "iutest_type_param_tests1.cpp"
 #include "iutest_type_param_tests2.cpp"
 #include "iutest_type_param_tests3.cpp"
