@@ -44,22 +44,3 @@ IUTEST_F(TestFixed, Test2)
 {
 	IUTEST_ASSERT_EQ(2, x);
 }
-
-#if IUTEST_HAS_PARAM_METHOD_TEST
-
-void TestFunction(int x, int y)
-{
-	IUTEST_ASSERT_EQ(x, y);
-}
-IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 0, 0);
-IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 1, 1);
-IUTEST_PMZ(ParamMethodTest, EQ, TestFunction, 2, 2);
-
-typedef TestFixed ParamMethodTestFixed;
-
-IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 0, 0);
-IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 1, 1);
-IUTEST_PMZ_F(ParamMethodTestFixed, EQ, TestFunction, 2, 2);
-
-#endif
-
